@@ -1,3 +1,11 @@
+"""
+Common helpers and adaptations for Py2/3.
+To be used in tests.
+"""
+
+# Slows down test runs by factors. Enable to debug proxy handling issues.
+DEBUG_PROXY_ISSUES = False  # True
+
 import gc
 import os
 import os.path
@@ -61,17 +69,15 @@ def filter_by_version(test_class, version_dict, current_version):
         if expected_version > current_version:
             setattr(test_class, name, dummy_test_method)
 
+
+def needs_libxml(*version):
+    return unittest.skipIf(
+        etree.LIBXML_VERSION < version,
+        "needs libxml2 >= %s.%s.%s" % (version + (0, 0, 0))[:3])
+
+
 import doctest
 
-try:
-    next
-except NameError:
-    def next(it):
-        return it.next()
-else:
-    locals()['next'] = next
-
-
 try:
     import pytest
 except ImportError:
@@ -161,7 +167,8 @@ except AttributeError:
 
 class HelperTestCase(unittest.TestCase):
     def tearDown(self):
-        gc.collect()
+        if DEBUG_PROXY_ISSUES:
+            gc.collect()
 
     def parse(self, text, parser=None):
         f = BytesIO(text) if isinstance(text, bytes) else StringIO(text)
@@ -244,6 +251,12 @@ class LargeFileLikeUnicode(LargeFileLike):
             yield self.chars
         yield _str('</root>')
 
+class SimpleFSPath(object):
+    def __init__(self, path):
+        self.path = path
+    def __fspath__(self):
+        return self.path
+
 def fileInTestDir(name):
     _testdir = os.path.dirname(__file__)
     return os.path.join(_testdir, name)
